You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@harmony.apache.org by hi...@apache.org on 2007/10/24 21:48:41 UTC

svn commit: r587981 - in /harmony/enhanced/classlib/trunk/modules/luni/src: main/java/java/lang/ main/java/java/net/ main/java/java/util/ main/java/org/apache/harmony/luni/internal/net/www/ main/java/org/apache/harmony/luni/util/ main/native/hyzip/shar...

Author: hindessm
Date: Wed Oct 24 12:48:39 2007
New Revision: 587981

URL: http://svn.apache.org/viewvc?rev=587981&view=rev
Log:
Spelling fixes.

Modified:
    harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/lang/CharSequence.java
    harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/net/InetSocketAddress.java
    harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/net/JarURLConnection.java
    harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/net/SecureCacheResponse.java
    harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/net/URI.java
    harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/util/FormattableFlags.java
    harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/util/Formatter.java
    harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/util/FormatterClosedException.java
    harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/util/IllegalFormatCodePointException.java
    harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/util/IllegalFormatException.java
    harmony/enhanced/classlib/trunk/modules/luni/src/main/java/org/apache/harmony/luni/internal/net/www/MimeTable.java
    harmony/enhanced/classlib/trunk/modules/luni/src/main/java/org/apache/harmony/luni/util/HexStringParser.java
    harmony/enhanced/classlib/trunk/modules/luni/src/main/native/hyzip/shared/hyzip.nls
    harmony/enhanced/classlib/trunk/modules/luni/src/main/native/luni/shared/OSNetworkSystem.c
    harmony/enhanced/classlib/trunk/modules/luni/src/main/native/luni/shared/bigint.c
    harmony/enhanced/classlib/trunk/modules/luni/src/main/native/luni/shared/cbigint.c
    harmony/enhanced/classlib/trunk/modules/luni/src/main/native/luni/shared/ois.c
    harmony/enhanced/classlib/trunk/modules/luni/src/main/native/luni/shared/socket.c
    harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/org/apache/harmony/luni/tests/java/lang/String2Test.java
    harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/io/FileInputStreamTest.java
    harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/io/FileOutputStreamTest.java
    harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/io/FilePermissionTest.java
    harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/io/RandomAccessFileTest.java
    harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/io/UTFDataFormatExceptionTest.java
    harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/lang/reflect/ConstructorTest.java
    harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/DatagramSocketTest.java
    harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/JarURLConnectionTest.java
    harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/NetworkInterfaceTest.java
    harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/ProxySelectorTest.java
    harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/URITest.java
    harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/URLTest.java
    harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/util/EnumSetTest.java
    harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/util/PropertyResourceBundleTest.java
    harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/util/ScannerTest.java

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/lang/CharSequence.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/lang/CharSequence.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/lang/CharSequence.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/lang/CharSequence.java Wed Oct 24 12:48:39 2007
@@ -27,7 +27,7 @@
 	/**
 	 * Answers the number of characters in the sequence.
 	 * 
-	 * @return the number of charcters in the sequence
+	 * @return the number of characters in the sequence
 	 */
 	public int length();
 

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/net/InetSocketAddress.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/net/InetSocketAddress.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/net/InetSocketAddress.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/net/InetSocketAddress.java Wed Oct 24 12:48:39 2007
@@ -52,7 +52,7 @@
     }
 
     /*
-     * Internal contructor for InetSocketAddress(String, int) and
+     * Internal constructor for InetSocketAddress(String, int) and
      * createUnresolved(String, int);
      */
     InetSocketAddress(String host, int port, boolean needResolved) {

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/net/JarURLConnection.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/net/JarURLConnection.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/net/JarURLConnection.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/net/JarURLConnection.java Wed Oct 24 12:48:39 2007
@@ -42,7 +42,7 @@
     private String file;
 
     /**
-     * Contructs an instance of <code>JarURLConnection</code>.
+     * Constructs an instance of <code>JarURLConnection</code>.
      * 
      * @param url
      *            java.net.URL the URL that contains the location to connect to

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/net/SecureCacheResponse.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/net/SecureCacheResponse.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/net/SecureCacheResponse.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/net/SecureCacheResponse.java Wed Oct 24 12:48:39 2007
@@ -22,7 +22,7 @@
 import javax.net.ssl.SSLPeerUnverifiedException;
 
 /**
- * A secure cache response, which is orignally retrieved through secure ways.
+ * A secure cache response, which is originally retrieved through secure ways.
  */
 public abstract class SecureCacheResponse extends CacheResponse {
     /**

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/net/URI.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/net/URI.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/net/URI.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/net/URI.java Wed Oct 24 12:48:39 2007
@@ -613,7 +613,7 @@
                     // case for a closed bracket at end of IP [x:x:x:...x]
                     case ']':
                         if (i != length - 1) {
-                            return false; // must be last charcter
+                            return false; // must be last character
                         }
                         if (ipAddress.charAt(0) != '[') {
                             return false; // must have a open [

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/util/FormattableFlags.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/util/FormattableFlags.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/util/FormattableFlags.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/util/FormattableFlags.java Wed Oct 24 12:48:39 2007
@@ -24,7 +24,7 @@
 public class FormattableFlags {
     
     private FormattableFlags(){
-        //prevent this class to be instantialized
+        //prevent this class from being instantiated
     }
     
     /**

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/util/Formatter.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/util/Formatter.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/util/Formatter.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/util/Formatter.java Wed Oct 24 12:48:39 2007
@@ -876,7 +876,7 @@
                     break;
                 }
                 case 'n': {
-                    result = transfromFromLineSeparator();
+                    result = transformFromLineSeparator();
                     break;
                 }
                 case 't':
@@ -1100,7 +1100,7 @@
          * Transforms line separator to a formatted string. Any flag, the width
          * or the precision is illegal.
          */
-        private String transfromFromLineSeparator() {
+        private String transformFromLineSeparator() {
             if (formatToken.isPrecisionSet()) {
                 throw new IllegalFormatPrecisionException(formatToken
                         .getPrecision());

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/util/FormatterClosedException.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/util/FormatterClosedException.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/util/FormatterClosedException.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/util/FormatterClosedException.java Wed Oct 24 12:48:39 2007
@@ -27,7 +27,7 @@
 	private static final long serialVersionUID = 18111216L;
 
 	/**
-	 * Constucts an instance of FormatterClosedException.
+	 * Constructs an instance of FormatterClosedException.
 	 * 
 	 */
 	public FormatterClosedException() {

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/util/IllegalFormatCodePointException.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/util/IllegalFormatCodePointException.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/util/IllegalFormatCodePointException.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/util/IllegalFormatCodePointException.java Wed Oct 24 12:48:39 2007
@@ -52,7 +52,7 @@
 	/**
 	 * Return the message string of the IllegalFormatCodePointException.
 	 * 
-	 * @retun The message string of the IllegalFormatCodePointException.
+	 * @return The message string of the IllegalFormatCodePointException.
 	 */
 	@Override
     public String getMessage() {

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/util/IllegalFormatException.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/util/IllegalFormatException.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/util/IllegalFormatException.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/main/java/java/util/IllegalFormatException.java Wed Oct 24 12:48:39 2007
@@ -20,10 +20,8 @@
 /**
  * Unchecked Exception that is to be thrown out when a format string that
  * contains either an illegal syntax or format specifier is transferred as a
- * parameter. Only subclass that is inherited explicitly from this exception is
- * allowed to be instantialized.
- * 
- * 
+ * parameter. Only a subclass that is inherited explicitly from this exception
+ * is allowed to be instantiated.
  */
 public class IllegalFormatException extends IllegalArgumentException implements
 		Serializable {

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/main/java/org/apache/harmony/luni/internal/net/www/MimeTable.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/main/java/org/apache/harmony/luni/internal/net/www/MimeTable.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/main/java/org/apache/harmony/luni/internal/net/www/MimeTable.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/main/java/org/apache/harmony/luni/internal/net/www/MimeTable.java Wed Oct 24 12:48:39 2007
@@ -51,7 +51,7 @@
     }
 
     /**
-     * Contructs a MIME table using the default values defined in this class.
+     * Constructs a MIME table using the default values defined in this class.
      * 
      * It then augments this table by reading pairs of extensions and
      * corresponding content types from the file "content-types.properties",

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/main/java/org/apache/harmony/luni/util/HexStringParser.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/main/java/org/apache/harmony/luni/util/HexStringParser.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/main/java/org/apache/harmony/luni/util/HexStringParser.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/main/java/org/apache/harmony/luni/util/HexStringParser.java Wed Oct 24 12:48:39 2007
@@ -304,13 +304,13 @@
     private int getOffset(String strIntegerPart, String strDecimalPart) {
         strIntegerPart = strIntegerPart.replaceFirst("^0+", ""); //$NON-NLS-1$ //$NON-NLS-2$
         
-        //If the Interger part is a nonzero number.
+        //If the Integer part is a nonzero number.
         if (strIntegerPart.length() != 0) {
             String leadingNumber = strIntegerPart.substring(0, 1);
             return (strIntegerPart.length() - 1) * 4 + countBitsLength(Long.parseLong(leadingNumber,HEX_RADIX)) - 1;
         }
         
-        //If the Interger part is a zero number.
+        //If the Integer part is a zero number.
         int i;
         for (i = 0; i < strDecimalPart.length() && strDecimalPart.charAt(i) == '0'; i++);   
         if (i == strDecimalPart.length()) {

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/main/native/hyzip/shared/hyzip.nls
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/main/native/hyzip/shared/hyzip.nls?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/main/native/hyzip/shared/hyzip.nls (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/main/native/hyzip/shared/hyzip.nls Wed Oct 24 12:48:39 2007
@@ -26,7 +26,7 @@
 # Note to translators:
 #
 # This file uses printf style substitutions. Sequences such as %s, %.*s, %10d
-# etc. will be subsituted at runtime. The special case of %% is not a substitution.
+# etc. will be substituted at runtime. The special case of %% is not a substitution.
 # It indicates a single percent sign. Please do not modify the format specifiers, or 
 # change their order. For instance, in a message like "from %d to %s", %d
 # MUST appear before %s in any translated message, or a run-time crash

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/main/native/luni/shared/OSNetworkSystem.c
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/main/native/luni/shared/OSNetworkSystem.c?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/main/native/luni/shared/OSNetworkSystem.c (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/main/native/luni/shared/OSNetworkSystem.c Wed Oct 24 12:48:39 2007
@@ -1442,7 +1442,7 @@
     }
   else
     {
-     /* update	the packet with	the legth of data received.
+     /* update	the packet with	the length of data received.
 	 Since we are connected	we did not get back an address.	 This
 	 address is cached within the PlainDatagramSocket  java	object and is filled in	at
 	 the java level	*/

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/main/native/luni/shared/bigint.c
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/main/native/luni/shared/bigint.c?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/main/native/luni/shared/bigint.c (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/main/native/luni/shared/bigint.c Wed Oct 24 12:48:39 2007
@@ -951,7 +951,7 @@
       shiftvalr = 64 - shiftval;
       lenR = len + newAt + 1;
 
-      /* attemp to pre-normalize */
+      /* attempt to pre-normalize */
       if (!(ar = (U_64 *) GET_ELEMENTS_CRITICAL (src)))
         goto error;
       if (shiftval == 0
@@ -1013,7 +1013,7 @@
             lenR = 1;
           else
             {
-              /* attemp to pre-normalize */
+              /* attempt to pre-normalize */
               if (!(ar = (U_64 *) GET_ELEMENTS_CRITICAL (src)))
                 goto error;
               if (shiftval != 0

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/main/native/luni/shared/cbigint.c
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/main/native/luni/shared/cbigint.c?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/main/native/luni/shared/cbigint.c (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/main/native/luni/shared/cbigint.c Wed Oct 24 12:48:39 2007
@@ -691,7 +691,7 @@
    */
   /* Replace the current implementaion which performs a
    * "multiplication" by 10 e number of times with an actual
-   * mulitplication. 10e19 is the largest exponent to the power of ten
+   * multiplication. 10e19 is the largest exponent to the power of ten
    * that will fit in a 64-bit integer, and 10e9 is the largest exponent to
    * the power of ten that will fit in a 64-bit integer. Not sure where the
    * break-even point is between an actual multiplication and a

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/main/native/luni/shared/ois.c
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/main/native/luni/shared/ois.c?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/main/native/luni/shared/ois.c (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/main/native/luni/shared/ois.c Wed Oct 24 12:48:39 2007
@@ -174,7 +174,7 @@
     }
   else
     {
-      /* Instantiate an object of a given class and constuct it using
+      /* Instantiate an object of a given class and construct it using
          the constructor of the other class. */
       jobject obj;
       obj = (*env)->AllocObject(env, instantiationClass);

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/main/native/luni/shared/socket.c
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/main/native/luni/shared/socket.c?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/main/native/luni/shared/socket.c (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/main/native/luni/shared/socket.c Wed Oct 24 12:48:39 2007
@@ -273,7 +273,7 @@
   U_32 interfaceIndex;
   U_32 scope_id = 0;
 
-  /* JNI objects needed to access the information in the optVal oject passed in */
+  /* JNI objects needed to access the information in the optVal object passed in */
   /* the object passed in is a GenericIPMreq object */
   jclass cls;
   jfieldID multiaddrID;
@@ -478,7 +478,7 @@
   U_32 interfaceIndex;
   U_32 scope_id = 0;
 
-/* JNI objects needed to access the information in the optVal oject passed in */
+/* JNI objects needed to access the information in the optVal object passed in */
   /* the object passed in is a GenericIPMreq object */
   jclass cls;
   jfieldID multiaddrID;

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/org/apache/harmony/luni/tests/java/lang/String2Test.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/org/apache/harmony/luni/tests/java/lang/String2Test.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/org/apache/harmony/luni/tests/java/lang/String2Test.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/org/apache/harmony/luni/tests/java/lang/String2Test.java Wed Oct 24 12:48:39 2007
@@ -366,7 +366,7 @@
                     assertEquals((byte) i, result[0]);
                 } else {
                     /*
-                     * Substitue character should be 0x1A [1], but may be '?'
+                     * Substitute character should be 0x1A [1], but may be '?'
                      * character. [1]
                      * http://en.wikipedia.org/wiki/Substitute_character
                      */

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/io/FileInputStreamTest.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/io/FileInputStreamTest.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/io/FileInputStreamTest.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/io/FileInputStreamTest.java Wed Oct 24 12:48:39 2007
@@ -351,7 +351,7 @@
 
         try {
             fis.read(new byte[1], 0, 5);
-            fail("IndexOutOfBoundsException must be thrown if off+len > b.lengh");
+            fail("IndexOutOfBoundsException must be thrown if off+len > b.length");
         } catch (IndexOutOfBoundsException e) {}
 
         try {

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/io/FileOutputStreamTest.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/io/FileOutputStreamTest.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/io/FileOutputStreamTest.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/io/FileOutputStreamTest.java Wed Oct 24 12:48:39 2007
@@ -196,7 +196,7 @@
 
         try {
             fos.write(new byte[1], 0, 5);
-            fail("IndexOutOfBoundsException must be thrown if off+len > b.lengh");
+            fail("IndexOutOfBoundsException must be thrown if off+len > b.length");
         } catch (IndexOutOfBoundsException e) {}
 
         try {

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/io/FilePermissionTest.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/io/FilePermissionTest.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/io/FilePermissionTest.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/io/FilePermissionTest.java Wed Oct 24 12:48:39 2007
@@ -48,7 +48,7 @@
 		assertEquals("action given to the constructor did not correspond - constructor failed",
 				"write", constructFile.getActions());
 		assertTrue(
-				"name given to the construcotr did not correspond - construcotr failed",
+				"name given to the constructor did not correspond - constructor failed",
 				constructFile.getName() == "test constructor");
 
         // Regression test for HARMONY-1050

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/io/RandomAccessFileTest.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/io/RandomAccessFileTest.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/io/RandomAccessFileTest.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/io/RandomAccessFileTest.java Wed Oct 24 12:48:39 2007
@@ -774,7 +774,7 @@
 
         try {
             raf.read(new byte[1], 0, 5);
-            fail("IndexOutOfBoundsException must be thrown if off+len > b.lengh");
+            fail("IndexOutOfBoundsException must be thrown if off+len > b.length");
         } catch (IndexOutOfBoundsException e) {
         }
 
@@ -878,7 +878,7 @@
 
         try {
             raf.write(new byte[1], 0, 5);
-            fail("IndexOutOfBoundsException must be thrown if off+len > b.lengh");
+            fail("IndexOutOfBoundsException must be thrown if off+len > b.length");
         } catch (IndexOutOfBoundsException e) {
         }
 
@@ -936,4 +936,4 @@
         super.tearDown();
     }
 
-}
\ No newline at end of file
+}

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/io/UTFDataFormatExceptionTest.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/io/UTFDataFormatExceptionTest.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/io/UTFDataFormatExceptionTest.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/io/UTFDataFormatExceptionTest.java Wed Oct 24 12:48:39 2007
@@ -41,7 +41,7 @@
 		} catch (UTFDataFormatException e) {
 			return;
 		} catch (Exception e) {
-			fail("Exeption during Constructor test : " + e.getMessage());
+			fail("Exception during Constructor test : " + e.getMessage());
 		}
 	}
 
@@ -63,7 +63,7 @@
 		} catch (UTFDataFormatException e) {
 			return;
 		} catch (Exception e) {
-			fail("Exeption during Constructor test : " + e.getMessage());
+			fail("Exception during Constructor test : " + e.getMessage());
 		}
 	}
 

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/lang/reflect/ConstructorTest.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/lang/reflect/ConstructorTest.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/lang/reflect/ConstructorTest.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/lang/reflect/ConstructorTest.java Wed Oct 24 12:48:39 2007
@@ -63,7 +63,7 @@
 		} catch (Exception e) {
 			fail("Exception during equals test : " + e.getMessage());
 		}
-		assertTrue("Different Contructors returned equal", !ctor1.equals(ctor2));
+		assertTrue("Different Constructors returned equal", !ctor1.equals(ctor2));
 	}
 
 	/**
@@ -160,7 +160,7 @@
 							.equals(
 									"tests.api.java.lang.reflect.ConstructorTest$ConstructorTestHelper"));
 		} catch (Exception e) {
-			fail("Exception obtaining contructor : " + e.getMessage());
+			fail("Exception obtaining constructor : " + e.getMessage());
 		}
 	}
 

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/DatagramSocketTest.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/DatagramSocketTest.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/DatagramSocketTest.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/DatagramSocketTest.java Wed Oct 24 12:48:39 2007
@@ -1139,7 +1139,7 @@
 				int portNumber = Support_PortManager.getNextPortForUDP();
 				ds = new java.net.DatagramSocket(new mySocketAddress());
 				fail(
-						"No exception when constucting datagramSocket with unsupported SocketAddress type");
+						"No exception when constructing datagramSocket with unsupported SocketAddress type");
 			} catch (IllegalArgumentException e) {
 
 			}

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/JarURLConnectionTest.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/JarURLConnectionTest.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/JarURLConnectionTest.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/JarURLConnectionTest.java Wed Oct 24 12:48:39 2007
@@ -242,7 +242,7 @@
         // equal but not same manifest
         assertEquals(mf,juc.getManifest());
         assertNotSame(mf,juc.getManifest());
-        // same main attrubutes
+        // same main attributes
         assertEquals(juc.getMainAttributes(),mf.getMainAttributes());
     }
 

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/NetworkInterfaceTest.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/NetworkInterfaceTest.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/NetworkInterfaceTest.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/NetworkInterfaceTest.java Wed Oct 24 12:48:39 2007
@@ -252,7 +252,7 @@
 			assertNotNull("validate that non null display name is returned",
 					networkInterface1.getDisplayName());
 			assertFalse(
-					"validate that non-zero lengtj display name is generated",
+					"validate that non-zero length display name is generated",
 					networkInterface1.getDisplayName().equals(""));
 		}
 		if (atLeastTwoInterfaces) {

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/ProxySelectorTest.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/ProxySelectorTest.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/URITest.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/URITest.java Wed Oct 24 12:48:39 2007
@@ -535,7 +535,7 @@
 
                 // hierarchical tests..
 
-                // diffrent authorities
+                // different authorities
                 { "//www.test.com/test", "//www.test2.com/test" },
 
                 { "/nullauth", "//nonnullauth/test" }, // one null authority
@@ -1443,7 +1443,7 @@
 
                 new URI("//fgj234fkgj.jhj.123"),
 
-                // '-' cannot be first or last charcter in a label
+                // '-' cannot be first or last character in a label
                 new URI("//-domain.name"), new URI("//domain.name-"),
                 new URI("//domain-"),
 

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/URLTest.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/URLTest.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/URLTest.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/URLTest.java Wed Oct 24 12:48:39 2007
@@ -1189,7 +1189,7 @@
 		URL ftpUrl = new URL("ftp://" + Support_Configuration.FTPTestAddress
 				+ "/nettest.txt");
 		URL[] urlList = { httpUrl, ftpUrl };
-		ProxySelector orignalSelector = ProxySelector.getDefault();
+		ProxySelector originalSelector = ProxySelector.getDefault();
 		ProxySelector.setDefault(new MockProxySelector());
 		try {
 			for (int i = 0; i < urlList.length; ++i) {
@@ -1205,8 +1205,7 @@
 								+ urlList[i], isSelectCalled);
 			}
 		} finally {
-			ProxySelector.setDefault(orignalSelector);
-
+			ProxySelector.setDefault(originalSelector);
 		}
 	}
     

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/util/EnumSetTest.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/util/EnumSetTest.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/util/EnumSetTest.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/util/EnumSetTest.java Wed Oct 24 12:48:39 2007
@@ -420,7 +420,7 @@
     /**
      * @tests java.util.EnumSet#remove(Object)
      */
-    public void test_remove_LOject() {
+    public void test_remove_LObject() {
         Set<EnumFoo> set = EnumSet.noneOf(EnumFoo.class);
         Enum[] elements = EnumFoo.class.getEnumConstants();
         for(int i = 0; i < elements.length; i++) {

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/util/PropertyResourceBundleTest.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/util/PropertyResourceBundleTest.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/util/PropertyResourceBundleTest.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/util/PropertyResourceBundleTest.java Wed Oct 24 12:48:39 2007
@@ -85,7 +85,7 @@
 			prb = new PropertyResourceBundle(propertiesStream);
 		} catch (java.io.IOException e) {
 			fail(
-					"Contruction of PropertyResourceBundle threw IOException");
+					"Construction of PropertyResourceBundle threw IOException");
 		}
 	}
 

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/util/ScannerTest.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/util/ScannerTest.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/util/ScannerTest.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/util/ScannerTest.java Wed Oct 24 12:48:39 2007
@@ -4798,7 +4798,7 @@
         mresult = s.match();
         assertEquals(0, mresult.start());
         assertEquals(2, mresult.end());
-        // Postion is now pointing at the bar. "12|345test1234test next"
+        // Position is now pointing at the bar. "12|345test1234test next"
 
         result = s.findWithinHorizon(Pattern.compile("\\p{Digit}+"), 6);
         assertEquals("345", result);
@@ -4806,7 +4806,7 @@
         mresult = s.match();
         assertEquals(2, mresult.start());
         assertEquals(5, mresult.end());
-        // Postion is now pointing at the bar. "12345|test1234test next"
+        // Position is now pointing at the bar. "12345|test1234test next"
 
         // If no such pattern is detected then the null is returned and the
         // scanner's position remains unchanged.
@@ -4822,7 +4822,7 @@
         assertEquals("345", mresult.group());
         assertEquals(2, mresult.start());
         assertEquals(5, mresult.end());
-        // Postion is now still pointing at the bar. "12345|test1234test next"
+        // Position is now still pointing at the bar. "12345|test1234test next"
 
         // If horizon is 0, then the horizon is ignored and this method
         // continues to search through the input looking for the specified
@@ -4831,7 +4831,7 @@
         mresult = s.match();
         assertEquals(9, mresult.start());
         assertEquals(13, mresult.end());
-        // Postion is now pointing at the bar. "12345test1234|test next"
+        // Position is now pointing at the bar. "12345test1234|test next"
 
         assertEquals("test", s.next());
         mresult = s.match();
--- harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/ProxySelectorTest.java (original)
+++ harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/ProxySelectorTest.java Wed Oct 24 12:48:39 2007
@@ -74,7 +74,7 @@
 	/*
 	 * Original system properties must be restored after running each test case.
 	 */
-	private Properties orignalSystemProperties;
+	private Properties originalSystemProperties;
 
 	/**
 	 * @tests java.net.ProxySelector#getDefault()
@@ -91,7 +91,7 @@
 	 * @tests java.net.ProxySelector#getDefault()
 	 */
 	public void test_getDefault_Security() {
-		SecurityManager orignalSecurityManager = System.getSecurityManager();
+		SecurityManager originalSecurityManager = System.getSecurityManager();
 		try {
 			System.setSecurityManager(new MockSecurityManager());
 		} catch (SecurityException e) {
@@ -105,7 +105,7 @@
 		} catch (SecurityException e) {
 			// expected
 		} finally {
-			System.setSecurityManager(orignalSecurityManager);
+			System.setSecurityManager(originalSecurityManager);
 		}
 	}
 
@@ -131,7 +131,7 @@
 	 */
 	public void test_setDefaultLjava_net_ProxySelector_Security() {
 		ProxySelector originalSelector = ProxySelector.getDefault();
-		SecurityManager orignalSecurityManager = System.getSecurityManager();
+		SecurityManager originalSecurityManager = System.getSecurityManager();
 		try {
 			System.setSecurityManager(new MockSecurityManager());
 		} catch (SecurityException e) {
@@ -146,7 +146,7 @@
 		} catch (SecurityException e) {
 			// expected
 		} finally {
-			System.setSecurityManager(orignalSecurityManager);
+			System.setSecurityManager(originalSecurityManager);
 			ProxySelector.setDefault(originalSelector);
 		}
 	}
@@ -621,15 +621,15 @@
 	protected void setUp() throws Exception {
 		super.setUp();
 		// save original system properties
-		orignalSystemProperties = (Properties) System.getProperties().clone();
+		originalSystemProperties = (Properties) System.getProperties().clone();
 	}
 
 	/*
 	 * @see junit.framework.TestCase#tearDown()
 	 */
 	protected void tearDown() throws Exception {
-		// restore orignal system properties
-		System.setProperties(orignalSystemProperties);
+		// restore original system properties
+		System.setProperties(originalSystemProperties);
 		super.tearDown();
 	}
 }

Modified: harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/URITest.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/luni/src/test/api/common/tests/api/java/net/URITest.java?rev=587981&r1=587980&r2=587981&view=diff
==============================================================================